# A python library repo template

## Create isolated python environment for development.

```
python3.9 -m venv .venv
source .venv/bin/activate
python3 -m pip install --upgrade pip
```

## Build project

```
python -m build
```